searchData={"items":[{"type":"module","title":"Vectoree","doc":"","ref":"Vectoree.html"},{"type":"module","title":"Vectoree.Tree","doc":"A module containing functions for interacting with the 'tree' data structure,\nthe latter being a key-value store (map) with keys being `TreePath` structs\nand a payload value of arbitrary type.","ref":"Vectoree.Tree.html"},{"type":"function","title":"Vectoree.Tree.children/2","doc":"Returns a map, filtered from the given tree, which contains the children for\nthe given path including the children's parent entry.","ref":"Vectoree.Tree.html#children/2"},{"type":"function","title":"Examples - Vectoree.Tree.children/2","doc":"iex> p0 = Vectoree.TreePath.new([\"data\", \"ext\", \"lore\"])\n    iex> p1 = Vectoree.TreePath.new([\"data\", \"ext\", \"b4\"])\n    iex> t = %{p0 => :payload, p1 => :payload} |> Vectoree.Tree.normalize()\n    iex> Vectoree.Tree.children(t, Vectoree.TreePath.new([\"data\", \"ext\"]))\n    %{\n      %Vectoree.TreePath{segments: [\"ext\", \"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"lore\", \"ext\", \"data\"]} => :payload,\n      %Vectoree.TreePath{segments: [\"b4\", \"ext\", \"data\"]} => :payload\n    }","ref":"Vectoree.Tree.html#children/2-examples"},{"type":"function","title":"Vectoree.Tree.delete/2","doc":"Deletes entries from the given tree, whose path (key) starts with the given\npath. When the empty path is given, then the entire tree is deleted. When any\nnon-existing path is given, the tree remains untouched. For any existing key,\nthe function either deletes a single entry or a subtree (including the\nsubtree's root entry).\n\nEntries which have been added as a result of normalization are kept.","ref":"Vectoree.Tree.html#delete/2"},{"type":"function","title":"Examples - Vectoree.Tree.delete/2","doc":"iex> p0 = Vectoree.TreePath.new([\"data\", \"ext\", \"lore\"])\n    iex> p1 = Vectoree.TreePath.new([\"data\", \"ext\", \"b4\"])\n    iex> p2 = Vectoree.TreePath.new([\"data\", \"self\", \"spot\"])\n    iex> t = %{p0 => :payload, p1 => :payload, p2 => :payload} |> Vectoree.Tree.normalize()\n    iex> t = Vectoree.Tree.delete(t, Vectoree.TreePath.new([\"data\", \"self\", \"spot\"]))\n    %{\n      %Vectoree.TreePath{segments: [\"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"ext\", \"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"lore\", \"ext\", \"data\"]} => :payload,\n      %Vectoree.TreePath{segments: [\"b4\", \"ext\", \"data\"]} => :payload,\n      %Vectoree.TreePath{segments: [\"self\", \"data\"]} => nil\n    }\n    iex> t = Vectoree.Tree.delete(t, Vectoree.TreePath.new([\"data\", \"ext\"]))\n    %{\n      %Vectoree.TreePath{segments: [\"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"self\", \"data\"]} => nil\n    }\n    iex> t = Vectoree.Tree.delete(t, Vectoree.TreePath.new([\"non\", \"existing\"]))\n    %{\n      %Vectoree.TreePath{segments: [\"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"self\", \"data\"]} => nil\n    }\n    iex> Vectoree.Tree.delete(t, Vectoree.TreePath.new([]))\n    %{}","ref":"Vectoree.Tree.html#delete/2-examples"},{"type":"function","title":"Vectoree.Tree.normalize/1","doc":"Modifies the given tree starting from the given path, so that all paths are\npresent in the key set, which are required to make the tree structure fully\npopulated. In other words, the tree is modified so that each entry in the\nmap has a particular 'parent' entry with the particular parent path.\n\nNormalized trees are required, e.g. when using the `Tree.children` function.\nIn general, navigating through a non-normalized tree does result in\nnon-deterministic behavior.","ref":"Vectoree.Tree.html#normalize/1"},{"type":"function","title":"Examples - Vectoree.Tree.normalize/1","doc":"iex> p = Vectoree.TreePath.new([\"data\", \"lore\"])\n    iex> Vectoree.Tree.normalize(%{p => :payload})\n    %{\n      %Vectoree.TreePath{segments: [\"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"lore\", \"data\"]} => :payload\n    }","ref":"Vectoree.Tree.html#normalize/1-examples"},{"type":"function","title":"Vectoree.Tree.normalize/2","doc":"","ref":"Vectoree.Tree.html#normalize/2"},{"type":"function","title":"Vectoree.Tree.payload/2","doc":"Fetches the payload (value) from the given tree for the given path (key).","ref":"Vectoree.Tree.html#payload/2"},{"type":"function","title":"Examples - Vectoree.Tree.payload/2","doc":"iex> p = Vectoree.TreePath.new([\"data\", \"lore\"])\n    iex> t = %{p => :payload} |> Vectoree.Tree.normalize()\n    iex> Vectoree.Tree.payload(t, p)\n    {:ok, :payload}","ref":"Vectoree.Tree.html#payload/2-examples"},{"type":"function","title":"Vectoree.Tree.size/1","doc":"Returns the size of the given tree, which conforms to the number of key-value\npairs (entries) in the underlying map.","ref":"Vectoree.Tree.html#size/1"},{"type":"function","title":"Examples - Vectoree.Tree.size/1","doc":"iex> p = Vectoree.TreePath.new([\"data\", \"lore\"])\n    iex> t = %{p => :payload} |> Vectoree.Tree.normalize()\n    iex> Vectoree.Tree.size(t)\n    2","ref":"Vectoree.Tree.html#size/1-examples"},{"type":"function","title":"Vectoree.Tree.subtree/2","doc":"Returns a map, filtered from the given tree, which contains the subtree for\nthe given path including the subtree's root entry.","ref":"Vectoree.Tree.html#subtree/2"},{"type":"function","title":"Examples - Vectoree.Tree.subtree/2","doc":"iex> p0 = Vectoree.TreePath.new([\"data\", \"ext\", \"lore\"])\n    iex> p1 = Vectoree.TreePath.new([\"data\", \"ext\", \"b4\"])\n    iex> p2 = Vectoree.TreePath.new([\"data\", \"self\", \"spot\"])\n    iex> t = %{p0 => :payload, p1 => :payload, p2 => :payload} |> Vectoree.Tree.normalize()\n    iex> Vectoree.Tree.subtree(t, Vectoree.TreePath.new([\"data\", \"ext\"]))\n    %{\n      %Vectoree.TreePath{segments: [\"ext\", \"data\"]} => nil,\n      %Vectoree.TreePath{segments: [\"lore\", \"ext\", \"data\"]} => :payload,\n      %Vectoree.TreePath{segments: [\"b4\", \"ext\", \"data\"]} => :payload\n    }","ref":"Vectoree.Tree.html#subtree/2-examples"},{"type":"module","title":"Vectoree.TreePath","doc":"A canonical path implementation for tree structures.\n\nThe functions in this module handle `TreePath` structs, which encapsulate\npath `segments` in a list in reverse order. There is no distinction between\nabsolute and relative paths. Printable representations of such a struct use\nthe dot `.` character as separator between segments.\n\nDevelopers should avoid creating the `TreePath` struct directly and instead\nrely on the functions provided by this module, including the provided sigil\nmacros.","ref":"Vectoree.TreePath.html"},{"type":"function","title":"Vectoree.TreePath.append/2","doc":"Returns a new struct with the `segment` being appended on the given path.","ref":"Vectoree.TreePath.html#append/2"},{"type":"function","title":"Examples - Vectoree.TreePath.append/2","doc":"iex> Vectoree.TreePath.append(~p\"\", \"data\")\n    %Vectoree.TreePath{segments: [\"data\"]}\n\n    iex> Vectoree.TreePath.append(~p\"data.lore\", \"b4\")\n    %Vectoree.TreePath{segments: [\"b4\", \"lore\", \"data\"]}\n\n    iex> Vectoree.TreePath.append(~p\"data.lore\", ~p\"b4.soong\")\n    %Vectoree.TreePath{segments: [\"soong\", \"b4\", \"lore\", \"data\"]}","ref":"Vectoree.TreePath.html#append/2-examples"},{"type":"function","title":"Vectoree.TreePath.base/1","doc":"Returns a new struct which wraps the base segment of the given path.","ref":"Vectoree.TreePath.html#base/1"},{"type":"function","title":"Examples - Vectoree.TreePath.base/1","doc":"iex> Vectoree.TreePath.base(~p\"\")\n    %Vectoree.TreePath{segments: []}\n\n    iex> Vectoree.TreePath.base(~p\"data\")\n    %Vectoree.TreePath{segments: [\"data\"]}\n\n    iex> Vectoree.TreePath.base(~p\"data.lore.b4\")\n    %Vectoree.TreePath{segments: [\"b4\"]}","ref":"Vectoree.TreePath.html#base/1-examples"},{"type":"function","title":"Vectoree.TreePath.basename/1","doc":"Returns the base segment name of the given path as a `BitString`.","ref":"Vectoree.TreePath.html#basename/1"},{"type":"function","title":"Examples - Vectoree.TreePath.basename/1","doc":"iex> Vectoree.TreePath.basename(~p\"\")\n    \"\"\n\n    iex> Vectoree.TreePath.basename(~p\"data\")\n    \"data\"\n\n    iex> Vectoree.TreePath.basename(~p\"data.lore.b4\")\n    \"b4\"","ref":"Vectoree.TreePath.html#basename/1-examples"},{"type":"function","title":"Vectoree.TreePath.ends_with?/2","doc":"Checks if a path ends with the given `suffix`.","ref":"Vectoree.TreePath.html#ends_with?/2"},{"type":"function","title":"Examples - Vectoree.TreePath.ends_with?/2","doc":"iex> Vectoree.TreePath.ends_with?(~p\"data.lore.b4\", \"b4\")\n    true\n\n    iex> Vectoree.TreePath.ends_with?(~p\"data.lore.b4\", \"lore\")\n    false\n\n    iex> Vectoree.TreePath.ends_with?(~p\"data.lore.b4\", ~p\"lore.b4\")\n    true","ref":"Vectoree.TreePath.html#ends_with?/2-examples"},{"type":"function","title":"Vectoree.TreePath.level/1","doc":"Returns the level of the path.\n\nThe level corresponds to the number of path segments.","ref":"Vectoree.TreePath.html#level/1"},{"type":"function","title":"Vectoree.TreePath.new/1","doc":"Creates a new struct from a singular `segment` or a list of `segments`.\n\nAn empty singular `segment` results in a struct with zero segments.\nLists of `segments` are filtered for empty elements. An empty list,\nalso as a consequence after filtering, results in a struct with zero\nsegments. Whitespace on each `segment` is preserved.","ref":"Vectoree.TreePath.html#new/1"},{"type":"function","title":"Examples - Vectoree.TreePath.new/1","doc":"By passing a singular segment:\n\n    iex> Vectoree.TreePath.new(\"data\")\n    %Vectoree.TreePath{segments: [\"data\"]}\n\n    iex> Vectoree.TreePath.new(\"  da ta  \")\n    %Vectoree.TreePath{segments: [\"  da ta  \"]}\n\n    iex> Vectoree.TreePath.new(\"  \")\n    %Vectoree.TreePath{segments: [\"  \"]}\n\n    iex> Vectoree.TreePath.new(\"\")\n    %Vectoree.TreePath{segments: []}\n\nBy passing a list of segments:\n\n    iex> Vectoree.TreePath.new([])\n    %Vectoree.TreePath{segments: []}\n\n    iex> Vectoree.TreePath.new([\"data\"])\n    %Vectoree.TreePath{segments: [\"data\"]}\n\n    iex> Vectoree.TreePath.new([\"  data  \", \"lo  re\", \"b4\"])\n    %Vectoree.TreePath{segments: [\"b4\", \"lo  re\", \"  data  \"]}","ref":"Vectoree.TreePath.html#new/1-examples"},{"type":"function","title":"Vectoree.TreePath.parent/1","doc":"Returns a new struct which wraps the parent segment of the given path.","ref":"Vectoree.TreePath.html#parent/1"},{"type":"function","title":"Examples - Vectoree.TreePath.parent/1","doc":"iex> Vectoree.TreePath.parent(~p\"\")\n    %Vectoree.TreePath{segments: []}\n\n    iex> Vectoree.TreePath.parent(~p\"data\")\n    %Vectoree.TreePath{segments: []}\n\n    iex> Vectoree.TreePath.parent(~p\"data.lore.b4\")\n    %Vectoree.TreePath{segments: [\"lore\", \"data\"]}","ref":"Vectoree.TreePath.html#parent/1-examples"},{"type":"function","title":"Vectoree.TreePath.root/1","doc":"Returns a new struct which wraps the root segment of the given path.","ref":"Vectoree.TreePath.html#root/1"},{"type":"function","title":"Examples - Vectoree.TreePath.root/1","doc":"iex> Vectoree.TreePath.root(~p\"\")\n    %Vectoree.TreePath{segments: []}\n\n    iex> Vectoree.TreePath.root(~p\"data\")\n    %Vectoree.TreePath{segments: [\"data\"]}\n\n    iex> Vectoree.TreePath.root(~p\"data.lore.b4\")\n    %Vectoree.TreePath{segments: [\"data\"]}","ref":"Vectoree.TreePath.html#root/1-examples"},{"type":"function","title":"Vectoree.TreePath.rootname/1","doc":"Returns the root segment name of the given path as a `BitString`.","ref":"Vectoree.TreePath.html#rootname/1"},{"type":"function","title":"Examples - Vectoree.TreePath.rootname/1","doc":"iex> Vectoree.TreePath.rootname(~p\"\")\n    \"\"\n\n    iex> Vectoree.TreePath.rootname(~p\"data\")\n    \"data\"\n\n    iex> Vectoree.TreePath.rootname(~p\"data.lore.b4\")\n    \"data\"","ref":"Vectoree.TreePath.html#rootname/1-examples"},{"type":"function","title":"Vectoree.TreePath.separator/0","doc":"Returns the path separator character as a `BitString`.","ref":"Vectoree.TreePath.html#separator/0"},{"type":"function","title":"Vectoree.TreePath.separator_replacement/0","doc":"Returns the path separator character replacement as a `BitString`.\n\nThe replacement is built using the underscore character `_` followed by\nthe Base64 encoded form of the separator character.","ref":"Vectoree.TreePath.html#separator_replacement/0"},{"type":"function","title":"Vectoree.TreePath.sibling/2","doc":"Returns a new struct which wraps a sibling of the given path.\n\n# Examples\n\n    iex> Vectoree.TreePath.sibling(~p\"data.lore\", \"b4\")\n    %Vectoree.TreePath{segments: [\"b4\", \"data\"]}\n\n    iex> Vectoree.TreePath.sibling(~p\"\", \"b4\")\n    %Vectoree.TreePath{segments: [\"b4\"]}","ref":"Vectoree.TreePath.html#sibling/2"},{"type":"macro","title":"Vectoree.TreePath.sigil_p/2","doc":"Handles the sigil `~p` for tree paths.","ref":"Vectoree.TreePath.html#sigil_p/2"},{"type":"macro","title":"Examples - Vectoree.TreePath.sigil_p/2","doc":"iex> ~p\"\"\n    %Vectoree.TreePath{segments: []}\n\n    iex> ~p\"data.lore.b4\"\n    %Vectoree.TreePath{segments: [\"b4\", \"lore\", \"data\"]}\n\n    iex> x = \"or\"\n    iex> ~p\"da#{:t}a.l#{x}e.b4\"\n    %Vectoree.TreePath{segments: [\"b4\", \"lore\", \"data\"]}","ref":"Vectoree.TreePath.html#sigil_p/2-examples"},{"type":"function","title":"Vectoree.TreePath.starts_with?/2","doc":"Checks if a path starts with the given `prefix`.","ref":"Vectoree.TreePath.html#starts_with?/2"},{"type":"function","title":"Examples - Vectoree.TreePath.starts_with?/2","doc":"iex> Vectoree.TreePath.starts_with?(~p\"data.lore.b4\", \"data\")\n    true\n\n    iex> Vectoree.TreePath.starts_with?(~p\"data.lore.b4\", \"lore\")\n    false\n\n    iex> Vectoree.TreePath.starts_with?(~p\"data.lore.b4\", ~p\"data.lore\")\n    true","ref":"Vectoree.TreePath.html#starts_with?/2-examples"},{"type":"function","title":"Vectoree.TreePath.wrap/1","doc":"Creates a new struct by wrapping the provided list of `segments`.\n\nThe given list is taken as-is, i.e. without any filtering and by\nexpecting it to be already in reversed order.","ref":"Vectoree.TreePath.html#wrap/1"},{"type":"function","title":"Examples - Vectoree.TreePath.wrap/1","doc":"Here wrapping a path named \"data.lore.b4\":\n\n    iex> Vectoree.TreePath.wrap([\"b4\", \"lore\", \"data\"])\n    %Vectoree.TreePath{segments: [\"b4\", \"lore\", \"data\"]}","ref":"Vectoree.TreePath.html#wrap/1-examples"},{"type":"type","title":"Vectoree.TreePath.t/0","doc":"","ref":"Vectoree.TreePath.html#t:t/0"},{"type":"behaviour","title":"Vectoree.TreeProcessor","doc":"","ref":"Vectoree.TreeProcessor.html"},{"type":"callback","title":"Vectoree.TreeProcessor.handle_notify/4","doc":"","ref":"Vectoree.TreeProcessor.html#c:handle_notify/4"},{"type":"type","title":"Vectoree.TreeProcessor.tree_map/0","doc":"","ref":"Vectoree.TreeProcessor.html#t:tree_map/0"},{"type":"type","title":"Vectoree.TreeProcessor.tree_path/0","doc":"","ref":"Vectoree.TreeProcessor.html#t:tree_path/0"},{"type":"module","title":"Vectoree.TreeServer","doc":"","ref":"Vectoree.TreeServer.html"},{"type":"function","title":"Vectoree.TreeServer.args2info/1","doc":"","ref":"Vectoree.TreeServer.html#args2info/1"},{"type":"function","title":"Vectoree.TreeServer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Vectoree.TreeServer.html#child_spec/1"},{"type":"function","title":"Vectoree.TreeServer.mount_source/1","doc":"","ref":"Vectoree.TreeServer.html#mount_source/1"},{"type":"function","title":"Vectoree.TreeServer.notify/2","doc":"","ref":"Vectoree.TreeServer.html#notify/2"},{"type":"function","title":"Vectoree.TreeServer.notify/3","doc":"","ref":"Vectoree.TreeServer.html#notify/3"},{"type":"function","title":"Vectoree.TreeServer.query/3","doc":"","ref":"Vectoree.TreeServer.html#query/3"},{"type":"function","title":"Vectoree.TreeServer.query_apply/5","doc":"","ref":"Vectoree.TreeServer.html#query_apply/5"},{"type":"function","title":"Vectoree.TreeServer.register_sink/1","doc":"","ref":"Vectoree.TreeServer.html#register_sink/1"},{"type":"function","title":"Vectoree.TreeServer.start_link/1","doc":"","ref":"Vectoree.TreeServer.html#start_link/1"},{"type":"function","title":"Vectoree.TreeServer.start_processor/4","doc":"","ref":"Vectoree.TreeServer.html#start_processor/4"},{"type":"function","title":"Vectoree.TreeServer.start_sink/3","doc":"","ref":"Vectoree.TreeServer.html#start_sink/3"},{"type":"function","title":"Vectoree.TreeServer.start_source/3","doc":"","ref":"Vectoree.TreeServer.html#start_source/3"},{"type":"function","title":"Vectoree.TreeServer.stop_processor/2","doc":"","ref":"Vectoree.TreeServer.html#stop_processor/2"},{"type":"function","title":"Vectoree.TreeServer.stop_sink/2","doc":"","ref":"Vectoree.TreeServer.html#stop_sink/2"},{"type":"function","title":"Vectoree.TreeServer.stop_source/2","doc":"","ref":"Vectoree.TreeServer.html#stop_source/2"},{"type":"behaviour","title":"Vectoree.TreeSink","doc":"","ref":"Vectoree.TreeSink.html"},{"type":"callback","title":"Vectoree.TreeSink.handle_notify/3","doc":"","ref":"Vectoree.TreeSink.html#c:handle_notify/3"},{"type":"type","title":"Vectoree.TreeSink.tree_map/0","doc":"","ref":"Vectoree.TreeSink.html#t:tree_map/0"},{"type":"type","title":"Vectoree.TreeSink.tree_path/0","doc":"","ref":"Vectoree.TreeSink.html#t:tree_path/0"},{"type":"module","title":"Vectoree.TreeSource","doc":"","ref":"Vectoree.TreeSource.html"},{"type":"type","title":"Vectoree.TreeSource.tree_map/0","doc":"","ref":"Vectoree.TreeSource.html#t:tree_map/0"},{"type":"type","title":"Vectoree.TreeSource.tree_path/0","doc":"","ref":"Vectoree.TreeSource.html#t:tree_path/0"}],"content_type":"text/markdown"}